==> credentials-2.1.5-sources.jar: com/cloudbees/plugins/credentials/common/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.common;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.CurrentSelection}: {@code
     * - current -}.
     * 
     * @return
     *     {@code - current -}
     */
    public static String AbstractIdCredentialsListBoxModel_CurrentSelection() {
        return holder.format("AbstractIdCredentialsListBoxModel.CurrentSelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.CurrentSelection}: {@code
     * - current -}.
     * 
     * @return
     *     {@code - current -}
     */
    public static Localizable _AbstractIdCredentialsListBoxModel_CurrentSelection() {
        return new Localizable(holder, "AbstractIdCredentialsListBoxModel.CurrentSelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.EmptySelection}: {@code -
     * none -}.
     * 
     * @return
     *     {@code - none -}
     */
    public static String AbstractIdCredentialsListBoxModel_EmptySelection() {
        return holder.format("AbstractIdCredentialsListBoxModel.EmptySelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.EmptySelection}: {@code -
     * none -}.
     * 
     * @return
     *     {@code - none -}
     */
    public static Localizable _AbstractIdCredentialsListBoxModel_EmptySelection() {
        return new Localizable(holder, "AbstractIdCredentialsListBoxModel.EmptySelection");
    }

}

==> credentials-2.6.1.1-sources.jar: com/cloudbees/plugins/credentials/common/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.common;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.CurrentSelection}: {@code

     * - current -}.
     * 
     * @return
     *     {@code - current -}
     */
    public static String AbstractIdCredentialsListBoxModel_CurrentSelection() {
        return holder.format("AbstractIdCredentialsListBoxModel.CurrentSelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.CurrentSelection}: {@code

     * - current -}.
     * 
     * @return
     *     {@code - current -}
     */
    public static Localizable _AbstractIdCredentialsListBoxModel_CurrentSelection() {
        return new Localizable(holder, "AbstractIdCredentialsListBoxModel.CurrentSelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.EmptySelection}: {@code -

     * none -}.
     * 
     * @return
     *     {@code - none -}
     */
    public static String AbstractIdCredentialsListBoxModel_EmptySelection() {
        return holder.format("AbstractIdCredentialsListBoxModel.EmptySelection");
    }

    /**
     * Key {@code AbstractIdCredentialsListBoxModel.EmptySelection}: {@code -

     * none -}.
     * 
     * @return
     *     {@code - none -}
     */
    public static Localizable _AbstractIdCredentialsListBoxModel_EmptySelection() {
        return new Localizable(holder, "AbstractIdCredentialsListBoxModel.EmptySelection");
    }

}
